@@ -19,9 +19,9 @@
 
 """Provides the default implementation for flat review for Orca."""
 
-__id__        = "$Id: flat_review.py 4412 2009-01-08 17:30:08Z wwalker $"
-__version__   = "$Revision: 4412 $"
-__date__      = "$Date: 2009-01-08 12:30:08 -0500 (Thu, 08 Jan 2009) $"
+__id__        = "$Id: flat_review.py 4471 2009-01-28 17:52:43Z wwalker $"
+__version__   = "$Revision: 4471 $"
+__date__      = "$Date: 2009-01-28 12:52:43 -0500 (Wed, 28 Jan 2009) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -36,7 +36,7 @@ import rolenames
 import settings
 
 from orca_i18n import _         # for gettext support
-from orca_i18n import Q_        # to provide qualified translatable strings
+from orca_i18n import C_        # to provide qualified translatable strings
 
 # [[[WDW - HACK Regular expression to split strings on whitespace
 # boundaries, which is what we'll use for word dividers instead of
@@ -376,16 +376,12 @@ class StateZone(Zone):
                     # Translators: this is in reference to a radio button being
                     # selected or not.
                     #
-                    # ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
-                    #
-                    speechState = Q_("radiobutton|selected")
+                    speechState = C_("radiobutton", "selected")
                 else:
                     # Translators: this is in reference to a radio button being
                     # selected or not.
                     #
-                    # ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
-                    #
-                    speechState = Q_("radiobutton|not selected")
+                    speechState = C_("radiobutton", "not selected")
                 brailleState = \
                     settings.brailleRadioButtonIndicators[stateCount]
 
