@@ -19,9 +19,9 @@
 
 """Displays a GUI for the Orca main window."""
 
-__id__        = "$Id: orca_gui_main.py 4617 2009-03-02 00:20:24Z wwalker $"
-__version__   = "$Revision: 4617 $"
-__date__      = "$Date: 2009-03-01 19:20:24 -0500 (Sun, 01 Mar 2009) $"
+__id__        = "$Id: orca_gui_main.py 4666 2009-04-07 15:50:52Z wwalker $"
+__version__   = "$Revision: 4666 $"
+__date__      = "$Date: 2009-04-07 11:50:52 -0400 (Tue, 07 Apr 2009) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -48,6 +48,17 @@ class OrcaMainGUI(orca_glade.GladeWrapper):
 
         mainWindow = self.get_widget("mainWindow")
         self.set_orca_icon(mainWindow)
+
+        accelGroup = gtk.AccelGroup()
+        mainWindow.add_accel_group(accelGroup)
+        helpButton = self.get_widget("helpButton")
+        (keyVal, modifierMask) = gtk.accelerator_parse("F1")
+        helpButton.add_accelerator("clicked",
+                                   accelGroup,
+                                   keyVal,
+                                   modifierMask,
+                                   0)
+
         mainWindow.show()
 
     def hideGUI(self):
