@@ -33,7 +33,7 @@ ngettext = gettext.ngettext
 
 # Tell gettext where to find localized strings.
 #
-localedir = os.path.join ("/usr", "share", "locale")
+localedir = os.path.join ("/export/home/wwalker/work/orca/branches/gnome-2-26/bld", "share", "locale")
 gettext.bindtextdomain ("orca", localedir)
 gettext.textdomain("orca")
 
