@@ -39,9 +39,9 @@ Each mode is defined below. The 4 bits of information listed here are:
     actual symbol or be inserted before the symbol.
 """
 
-__id__  = "$Id: punctuation_settings.py 3882 2008-05-07 18:22:10Z richb $"
-__version__   = "$Revision: 3882 $"
-__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__id__  = "$Id: punctuation_settings.py 4411 2009-01-08 15:09:09Z wwalker $"
+__version__   = "$Revision: 4411 $"
+__date__      = "$Date: 2009-01-08 10:09:09 -0500 (Thu, 08 Jan 2009) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -105,8 +105,10 @@ divide               =  u'\u00f7'
 en_dash              =  u'\u2013'
 left_single_quote    =  u'\u2018'
 right_single_quote   =  u'\u2019'
+single_low_quote     =  u'\u201a'
 left_double_quote    =  u'\u201c'
 right_double_quote   =  u'\u201d'
+double_low_quote     =  u'\u201e'
 dagger               =  u'\u2020'
 double_dagger        =  u'\u2021'
 per_mille            =  u'\u2030'
@@ -157,7 +159,8 @@ punctuation[left_single_quote]  =  [ LEVEL_MOST, PUNCTUATION_REPLACE ]
 punctuation[left_double_quote]  =  [ LEVEL_MOST, PUNCTUATION_REPLACE ]
 punctuation[right_double_quote] =  [ LEVEL_MOST, PUNCTUATION_REPLACE ]
 punctuation[en_dash]            =  [ LEVEL_MOST, PUNCTUATION_REPLACE ]
-
+punctuation[double_low_quote]   =  [ LEVEL_MOST, PUNCTUATION_REPLACE ]
+punctuation[single_low_quote]   =  [ LEVEL_MOST, PUNCTUATION_REPLACE ]
 punctuation["#"] =  [ LEVEL_SOME, PUNCTUATION_REPLACE ]
 punctuation["$"] =  [ LEVEL_SOME, PUNCTUATION_REPLACE ]
 punctuation["%"] =  [ LEVEL_SOME, PUNCTUATION_REPLACE ]
