@@ -31,9 +31,9 @@
 
 """Custom script for StarOffice and OpenOffice."""
 
-__id__        = "$Id: script.py 4613 2009-02-27 23:32:29Z joanied $"
-__version__   = "$Revision: 4613 $"
-__date__      = "$Date: 2009-02-27 18:32:29 -0500 (Fri, 27 Feb 2009) $"
+__id__        = "$Id: script.py 4674 2009-04-10 13:39:24Z wwalker $"
+__version__   = "$Revision: 4674 $"
+__date__      = "$Date: 2009-04-10 09:39:24 -0400 (Fri, 10 Apr 2009) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -112,18 +112,14 @@ class Script(default.Script):
         #
         self.commFailureAttemptLimit = 1
 
-        # The default set of text attributes to speak to the user. The
-        # only difference over the default set in settings.py is to add
-        # in "left-margin:" and "right-margin:".
-
-        self.enabledBrailledTextAttributes = \
-          "size:; family-name:; weight:400; indent:0mm; left-margin:0mm; " \
-          "right-margin:0mm; underline:none; strikethrough:none; " \
-          "justification:left; style:normal;"
-        self.enabledSpokenTextAttributes = \
-          "size:; family-name:; weight:400; indent:0mm; left-margin:0mm; " \
-          "right-margin:0mm; underline:none; strikethrough:none; " \
-          "justification:left; style:normal;"
+        # Additional default set of text attributes to present to the
+        # user. The only difference over the default set in
+        # settings.py is to add in "left-margin:" and "right-margin:".
+        #
+        self.additionalBrailledTextAttributes = \
+          " left-margin:0mm; right-margin:0mm;"
+        self.additionalSpokenTextAttributes = \
+          " left-margin:0mm; right-margin:0mm;"
 
     def activate(self):
         """Called when this script is activated."""
@@ -132,12 +128,34 @@ class Script(default.Script):
 
         self.savedEnabledBrailledTextAttributes = \
             settings.enabledBrailledTextAttributes
-        settings.enabledBrailledTextAttributes = \
-            self.enabledBrailledTextAttributes
+        settings.enabledBrailledTextAttributes += \
+            self.additionalBrailledTextAttributes
 
         self.savedEnabledSpokenTextAttributes = \
             settings.enabledSpokenTextAttributes
-        settings.enabledSpokenTextAttributes = self.enabledSpokenTextAttributes
+        settings.enabledSpokenTextAttributes += \
+            self.additionalSpokenTextAttributes
+
+        # Account for the differences in how OOo expresses indent and
+        # strikethrough.
+        #
+        settings.enabledBrailledTextAttributes = \
+            settings.enabledBrailledTextAttributes.replace(
+            "strikethrough:false;",
+            "strikethrough:none;")
+        settings.enabledSpokenTextAttributes = \
+            settings.enabledSpokenTextAttributes.replace(
+            "strikethrough:false;",
+            "strikethrough:none;")
+
+        settings.enabledBrailledTextAttributes = \
+            settings.enabledBrailledTextAttributes.replace(
+            "indent:0;",
+            "indent:0mm;")
+        settings.enabledSpokenTextAttributes = \
+            settings.enabledSpokenTextAttributes.replace(
+            "indent:0;",
+            "indent:0mm;")
 
     def deactivate(self):
         """Called when this script is deactivated."""
@@ -2137,7 +2155,26 @@ class Script(default.Script):
         """
         rv, start, end = \
             default.Script.getTextAttributes(self, acc, offset, get_defaults)
-        return rv, start, end - 1
+
+        # If there are no text attributes associated with the text at a
+        # given offset, we might get some seriously bogus offsets, in
+        # particular, an extremely large start offset and an extremely
+        # large, but negative end offset. As a result, any text attributes
+        # which are present on the line after the specified offset will
+        # not be indicated by braille.py's getAttributeMask. Therefore,
+        # we'll set the start offset to the character being examined,
+        # and the end offset to the next character.
+        #
+        start = min(start, offset)
+        if end < 0:
+            debug.println(debug.LEVEL_WARNING,
+                "soffice.script.py:getTextAttributes: detected a bogus " +
+                "end offset. Start offset: %s, end offset: %s" % (start, end))
+            end = offset + 1
+        else:
+            end -= 1
+
+        return rv, start, end
 
     def getDisplayedText(self, obj):
         """Returns the text being displayed for an object. Overridden here
