@@ -23,9 +23,9 @@ implementation in Gecko:
 http://developer.mozilla.org/en/docs/Accessibility/ATSPI_Support
 """
 
-__id__        = "$Id: speech_generator.py 4534 2009-02-13 00:51:45Z wwalker $"
-__version__   = "$Revision: 4534 $"
-__date__      = "$Date: 2009-02-12 19:51:45 -0500 (Thu, 12 Feb 2009) $"
+__id__        = "$Id: speech_generator.py 4575 2009-02-18 16:22:18Z wwalker $"
+__version__   = "$Revision: 4575 $"
+__date__      = "$Date: 2009-02-18 11:22:18 -0500 (Wed, 18 Feb 2009) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -82,25 +82,14 @@ class SpeechGenerator(speechgenerator.SpeechGenerator):
             if obj.getRole() == pyatspi.ROLE_HEADING:
                 level = self._script.getHeadingLevel(obj)
                 if level:
-                    # Translators: the %d is in reference to a heading
+                    # Translators: the %(level)d is in reference to a heading
                     # level in HTML (e.g., For <h3>, the level is 3)
-                    # and the %s is in reference to a previously
-                    # translated rolename for the heading.  If you
-                    # change the order of the %s and %d in the string
-                    # (as needed for Hungarian, for example), Orca will
-                    # detect it and do the right thing.
+                    # and the %(role)s is in reference to a previously
+                    # translated rolename for the heading.
                     #
-                    headingString = _("%s level %d")
-                    if headingString.index("%s") < headingString.index("%d"):
-                        utterances.append(
-                            headingString \
-                            % (rolenames.getSpeechForRoleName(obj, role),
-                               level))
-                    else:
-                        utterances.append(
-                            headingString \
-                            % (level,
-                               rolenames.getSpeechForRoleName(obj, role)))
+                    utterances.append(_("%(role)s level %(level)d") % {
+                        'role': rolenames.getSpeechForRoleName(obj, role),
+                        'level': level})
                 else:
                     utterances.append(rolenames.getSpeechForRoleName(obj, role))
             else:
