@@ -21,9 +21,9 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 4507 2009-02-08 19:37:37Z wwalker $"
-__version__   = "$Revision: 4507 $"
-__date__      = "$Date: 2009-02-08 14:37:37 -0500 (Sun, 08 Feb 2009) $"
+__id__        = "$Id: settings.py 4674 2009-04-10 13:39:24Z wwalker $"
+__version__   = "$Revision: 4674 $"
+__date__      = "$Date: 2009-04-10 09:39:24 -0400 (Fri, 10 Apr 2009) $"
 __copyright__ = "Copyright (c) 2004-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -687,7 +687,8 @@ allTextAttributes = \
 
 enabledSpokenTextAttributes = \
     "size:; family-name:; weight:400; indent:0; underline:none; " \
-    "strikethrough:false; justification:left; style:normal;"
+    "strikethrough:false; justification:left; style:normal; " \
+    "paragraph-style:;"
 
 # The default set of text attributes to be brailled for the user. Specific
 # application scripts (or individual users can override these values if
